searchNodes=[{"doc":"It filters request params keeping only explicitly enumerated parameters.","ref":"StrongParams.html","title":"StrongParams","type":"module"},{"doc":"Macro to add filter for action parameters.It adds a Plug to filter request params before Phoenix call the respective controller action. This macro must be called inside a Phoenix controller implementation.The first given argument must be a valid action name. The second must be a Keyword with the list of required and permitted parameters. The Keyword may have both lists or just one of them::permitted - List of parameters to keep. If some of listed parameters is missing no error is returned.:required - List of parameters that are required. In case of missing parameters a error will be returned with a map enumerating the missing parameters.filter_for(:index, required: [:name, :email], permitted: [:nickname])For nested parameters you must use a keyword.Exemple:filter_for(:index, required: [:name, :email, address: [:street, :city]], permitted: [:nickname]) # Expected filtered parameters %{ name: &quot;Johnny Lawrence&quot;, nickname: &quot;John&quot;, email: &quot;john@mail.com&quot;, address: %{ street: &quot;5º Avenue&quot;, city: &quot;NY&quot; } }For a list of params you must use a nested listExample:filter_for(:create, required: [:name, attachments: [[:name]]]) # Expected filtered parameters %{ name: &quot;Johnny Lawrence&quot;, attachments: [ %{name: &quot;file.jpg&quot;}, %{name: &quot;doc.pdf&quot;} ] }Cast valueEcto.Type is used to the casting, so ecto needs to be available as a dependency in your app.Add to your mix.exs.{:ecto, &quot;~&gt; x.x&quot;}To cast values you must provide a tuple {field, type}Example:filter_for(:create, required: [{:id, Ecto.UUID}, {:date, {:array, :date}}]) # Expected filtered parameters %{ id: &quot;11268bd3-5e41-4e6f-bf28-f3e167f87767&quot;, dates: [~D[2021-11-29], ~D[2021-11-30]] }Any custom Ecto.Type or ecto primitive types are valid types.","ref":"StrongParams.html#filter_for/2","title":"StrongParams.filter_for/2","type":"macro"},{"doc":"","ref":"StrongParams.html#t:filters/0","title":"StrongParams.filters/0","type":"type"},{"doc":"","ref":"StrongParams.html#t:parameters_list/0","title":"StrongParams.parameters_list/0","type":"type"},{"doc":"This module defines a StrongParams.Error.t/0 struct that stores filtering errors.When using Phoenix action_fallback the fallback module will receive a tuple of {:error, %StrongParams.Error{}}defmodule YourPhoenixApp.Fallback do def call(conn, %StrongParams.Error{}) do send_resp(conn, 400, &quot;Your custom msg&quot;) end end","ref":"StrongParams.Error.html","title":"StrongParams.Error","type":"module"},{"doc":"","ref":"StrongParams.Error.html#t:errors_map/0","title":"StrongParams.Error.errors_map/0","type":"type"},{"doc":"","ref":"StrongParams.Error.html#t:t/0","title":"StrongParams.Error.t/0","type":"type"},{"doc":"StrongParams Inspired by Ruby on Rails Strong Parameters. It filters request params keeping only explicitly enumerated parameters.In addition, parameters can be marked as required and flow through a controller fallback flow to end up as a 400 Bad Request with no effort.","ref":"readme.html","title":"Get starting","type":"extras"},{"doc":"Add StrongParams to your applicationmix.exsdef deps do [ {:strong_params, &quot;~&gt; 0.2.0&quot;} ] endUpdate depsmix deps.get","ref":"readme.html#installation","title":"Get starting - Installation","type":"extras"},{"doc":"StrongParams uses macros to apply the parameters filter. You must use StrongParams in each controller you want filter parameters. The better way is using StrongParams in you Phoenix App entrypoint inside controller/0 block (it must be add after use Phoenix.Controller)./lib/your_phoenix_app.exdefmodule YourPhoenixApp do ... def controller do quote do use Phoenix.Controller, namespace: YourPhoenixApp use StrongParams ... end end endThen you can use macro filter_for/2 inside your controller to apply the filters for each action.defmodule YourPhoenixApp.UserController do use YourPhoenixApp, :controller alias YourPhoenixApp.User filter_for(:create, required: [:name, :email], permitted: [:nickname]) def create(conn, %{name: _, email: _} = params) do user = %User{} |&gt; User.changeset(params) |&gt; Repo.insert() render(conn, user: user) end endIn above example, once filter_for/2 is defined for action create the second argument received in action will be the filtered request parameters. The map params has atomized keys, once the filter is defined as atoms (the lib don't create new atoms).If some parameter enumerated as required is missing in received request the Plug.Conn will be halted with status code 400 and a generic error message. If you add an action fallback you can handle the filter error:defmodule YourPhoenixApp.UserController do use YourPhoenixApp, :controller action_fallback(YourPhoenixApp.Fallback) filter_for(:create, required: [:name, :email], permitted: [:nickname]) ... end defmodule YourPhoenixApp.Fallback do alias StrongParams.Error def call(conn, %Error{errors: errors}) do send_resp(conn, 400, &quot;Your custom msg \#{inpect(errors)}&quot;) end endYou must call filter_for/2 for each action you want to filter the params.filter_for(:create, required: [:name, :email], permitted: [:nickname]) filter_for(:update, permitted: [:name, :email, :nickname])","ref":"readme.html#usage","title":"Get starting - Usage","type":"extras"},{"doc":"Contributing Guide","ref":"readme.html#contributing","title":"Get starting - Contributing","type":"extras"},{"doc":"Apache License, Version 2.0 © brainn.co","ref":"readme.html#license","title":"Get starting - License","type":"extras"}]